@@ -46,10 +46,8 @@ int main(int argc, char *argv[])
     }
     viewer.setViewport(new QGLWidget());
 #endif
-
-    viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
-    viewer.show();
+    viewer.showFullScreen();
 
     return app.exec();
 }
