@@ -38,6 +38,7 @@ function getArchiveVideos() {
 
 function moveToArchive(video) {
     Settings.addVideoToArchive(video);
+    Settings.removeStoredDownload(video.filePath);
     archiveModel.insert(0, video);
     downloadModel.remove(downloadModel.currentDownload);
     downloadModel.getNextDownload();
@@ -56,6 +57,38 @@ function signInToDefaultAccount() {
     }
 }
 
+function getSubscriptions() {
+    /* Retrieve the user's subscriptions and
+      populate the model */
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            subscriptionsModel.xml = xml;
+        }
+    }
+    doc.open("GET", "http://gdata.youtube.com/feeds/api/users/default/subscriptions?v=2");
+    doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
+    doc.send();
+}
+
+function getPlaylists() {
+    /* Retrieve the user's subscriptions and
+      populate the model */
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            playlistModel.xml = xml;
+        }
+    }
+    doc.open("GET", "http://gdata.youtube.com/feeds/api/users/default/playlists?v=2");
+    doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
+    doc.send();
+}
+
 function goHome() {
     windowView.currentIndex = 0;
     notificationArea.titleList = ["cuteTube"];
@@ -169,32 +202,40 @@ function loadDownloads() {
     windowView.incrementCurrentIndex();
 }
 
-function youtubeSearch(query) {
+function youtubeSearch(query, order) {
     /* Perform a YouTube search and open video list window */
 
+    var searchOrder = order;
+    if (order == "date") {
+        searchOrder = "published";
+    }
+    else if (order == "views") {
+        searchOrder = "viewCount";
+    }
+
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
-                     + query.replace(" ", "+"));
+                     + query.replace(" ", "+") + "&orderby=" + searchOrder);
     loadVideos(videoFeed, "Search ('" + query + "')");
 }
 
-function search(query) {
+function search(query, order) {
     /* Check if xTube is installed and parse the search query */
 
     if (xTubeInstalled) {
         var youjizz = /^yj:/i;
         var xhamster = /^xh:/i;
         if (youjizz.test(query)) {
-            youjizzSearch(query.substr(3));
+            youjizzSearch(query.substr(3), order);
         }
         else if (xhamster.test(query)) {
-            xhamsterSearch(query.substr(3));
+            xhamsterSearch(query.substr(3), order);
         }
         else {
-            youtubeSearch(query);
+            youtubeSearch(query, order);
         }
     }
     else {
-        youtubeSearch(query);
+        youtubeSearch(query, order);
     }
 }
 
